@@ -3,6 +3,15 @@ import types
 from functools import lru_cache
 from inspect import isclass
 
+import redis
+
+
+@lru_cache(None)
+def get_redis_connection() -> redis.client.Redis:
+    from . import conf
+
+    return redis.from_url(conf.SMART_LOG_REDIS)
+
 
 @lru_cache(100)
 def fqn(o, silent=False, from_module=None):
